# TAC Controller Contract

This is a controller agent for a Trading Agent Competition (TAC) using smart contracts.

## Description

This agent is part of the Fetch.ai TAC demo. 

It uses its `fetchai/tac_control` skill to manage the progression of a competition across various stages, and uses its `fetchai/tac_control_contract` skill to create and maintain a smart contract (for example, deploying the contract, creating and minting tokens, etc).

## Links

* <a href="https://docs.fetch.ai/aea/tac-skills-contract/" target="_blank">TAC Demo</a>
